==> reveal.js-verticator-1.1.1.tgz: package/CHANGELOG.md <==
# Changelog

## [1.1.1] - 2020-03-07
### Added
- Added a new `tooltip` option
- Added a new `scale` option
- Started keeping the changelog.

### Changed
- Verticator will scale according to the scale factor of the main slides



## [1.1.0] - 2021-02-15
### Added
- Added the option to turn of the autogeneration of Verticator bullets.



## [1.0.9] - 2021-09-04
### Added
- Support for Verticator bullets on the left-hand side.
- An option to set the Verticator bullets offset off the edge of the presentation.



## [1.0.8] - 2020-10-23
### Changed
- Fixed an issue when "hashOneBasedIndex" is set to true. 
- Fixed an issue with Safari where the color of the bullets would not update.



## [1.0.7] - 2020-07-10
### Changed
- Verticator 1.0.7 now works with multiple Reveal.js instances. Verticator no longer wites a style block, but the colors are injected in the HTML. This way each Reveal instance can have its own colors.



## [1.0.6] - 2020-06-18
### Added
- Added auto-insert of ul.verticator if it does not exist. 
- Added npm install option.



## [1.0.5] - 2020-06-07
### Changed
- Bug fix of demo file of 1.0.4.
- Documentation changes by Salim B.



## [1.0.4] - 2020-06-07
### Added
- Configuration options (by Jochen Wierum) added
### Changed
- Changes of some formatting.
- Verticator now references the Reveal files by CDN.



## [1.0.3] - 2020-05-25
### Added
- Added compatibility with the new Reveal.js 4 that changes the way plugins work.



## [1.0.2] - 2020-05-22
### Added
- The 1.0.2 release is compatible with Reveal.js 3. The next release will only be compatible with Reveal.js 4.

==> reveal.js-verticator-1.1.2.tgz: package/CHANGELOG.md <==
# Changelog

## [1.1.1] - 2020-03-07
### Added
- Added a new `tooltip` option
- Added a new `scale` option
- Started keeping the changelog.

### Changed
- Verticator will now scale according to the scale factor of the main slides



## [1.1.0] - 2021-02-15
### Added
- Added the option to turn of the autogeneration of Verticator bullets.



## [1.0.9] - 2021-09-04
### Added
- Support for Verticator bullets on the left-hand side.
- An option to set the Verticator bullets offset off the edge of the presentation.



## [1.0.8] - 2020-10-23
### Changed
- Fixed an issue when "hashOneBasedIndex" is set to true. 
- Fixed an issue with Safari where the color of the bullets would not update.



## [1.0.7] - 2020-07-10
### Changed
- Verticator 1.0.7 now works with multiple Reveal.js instances. Verticator no longer wites a style block, but the colors are injected in the HTML. This way each Reveal instance can have its own colors.



## [1.0.6] - 2020-06-18
### Added
- Added auto-insert of ul.verticator if it does not exist. 
- Added npm install option.



## [1.0.5] - 2020-06-07
### Changed
- Bug fix of demo file of 1.0.4.
- Documentation changes by Salim B.



## [1.0.4] - 2020-06-07
### Added
- Configuration options (by Jochen Wierum) added
### Changed
- Changes of some formatting.
- Verticator now references the Reveal files by CDN.



## [1.0.3] - 2020-05-25
### Added
- Added compatibility with the new Reveal.js 4 that changes the way plugins work.



## [1.0.2] - 2020-05-22
### Added
- The 1.0.2 release is compatible with Reveal.js 3. The next release will only be compatible with Reveal.js 4.
